%define	oname CImg

Summary:	Tools for advanced image processing
Name:		cimg
Version:	3.2.5
%define subrel 1
Release:	%mkrel 1
License:	CeCiLLv2
Group:		Graphics/Utilities
URL:		https://cimg.eu/
Source0:	https://cimg.eu/files/CImg_%{version}.zip
Patch1:		CImg-linking.patch
Patch2:		CVE-2024-26540-1.patch
Patch3:		CVE-2024-26540-2.patch
Patch4:		CVE-2024-26540-3.patch
Patch5:		CVE-2024-26540-4.patch
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(GraphicsMagick++)
BuildRequires:	doxygen

%description
Image manipulation tools based on the CImg library, including the
greycstoration noise reduction tool.

%package   devel
Summary:   Library for advanced image processing (development files)
Group:     Development/C++
Requires:  pkgconfig(OpenEXR)
Provides:  CImg-devel = %{version}-%{release}

%description devel
The CImg Library is a C++ toolkit providing simple classes and functions to
load, save, process and display images in your own C++ code. It consists
only of a single header file CImg.h that must be included in your program
source. It contains useful image processing algorithms for loading/saving,
resizing/rotating, filtering, object drawing (text, lines, faces,
ellipses, ...), etc.

Images are instanciated by a class able to represent images up to 4-dimension
wide (from 1-D scalar signals to 3-D volumes of vector-valued pixels), with
template pixel types. It depends on a minimal number of libraries: you can
compile it with only standard C libraries. No need for exotic libraries and
complex dependencies.

%prep
%autosetup -n %{oname}-%{version} -p1

# build with GraphicsMagick++
sed -i -e '/PKG_CHECK_MODULES/s/\(\s\+\)Magick++/\1GraphicsMagick++/' examples/CMakeLists.txt

%build
%global _vpath_srcdir examples
%cmake -GNinja
%cmake_build

%install
%global demos CImg_demo captcha curve_editor2d dtmri_view3d  edge_explorer2d  fade_images  gaussian_fit1d generate_loop_macros hough_transform2d image_registration2d image2ascii image_surface3d jawbreaker mcf_levelsets2d mcf_levelsets3d odykill pde_heatflow2d pde_TschumperleDeriche2d plotter1d radon_transform2d scene3d spherical_function3d tetris tron tutorial wavelet_atrous use_draw_gradient use_nlmeans use_skeleton use_RGBclass

for d in %{demos}; do
  install -Dpm755 examples/$d %{buildroot}%{_bindir}/$d
done

mkdir -p %{buildroot}%{_includedir}/%{oname}
cp -a plugins %{buildroot}%{_includedir}/%{oname}
cp -a %{oname}.h %{buildroot}%{_includedir}/%{oname}
ln -s %{oname}/%{oname}.h %{buildroot}%{_includedir}/%{oname}.h

%files
%doc README.txt
%license Licence*
%{_bindir}/*

%files devel
%{_includedir}/%{oname}*
%doc README.txt Licence_CeCILL*


%changelog
* Fri May 23 2025 ns80 <ns80> 3.2.5-1.1.mga9
+ Revision: 2185995
- add patches from Ubuntu for CVE-2024-26540 (mga#34214)

* Sat Jun 10 2023 daviddavid <daviddavid> 3.2.5-1.mga9
+ Revision: 1961607
- new version: 3.2.5
+ wally <wally>
- build examples with cmake + ninja
- enable debug pkg
- drop example sources from docs

* Tue Jan 17 2023 daviddavid <daviddavid> 3.2.0-1.mga9
+ Revision: 1934127
- new version: 3.2.0

* Fri Jan 06 2023 papoteur <papoteur> 3.1.6-3.mga9
+ Revision: 1930728
- remove applying patch for ARM

* Fri Jan 06 2023 papoteur <papoteur> 3.1.6-2.mga9
+ Revision: 1930602
- remove patch about mtune=generic flag on ARM, dealt in Makefile

* Fri Jan 06 2023 papoteur <papoteur> 3.1.6-1.mga9
+ Revision: 1930558
- new 3.1.6

* Fri Apr 01 2022 umeabot <umeabot> 2.9.7-3.mga9
+ Revision: 1838120
- Mageia 9 Mass Rebuild

* Sun Jan 09 2022 wally <wally> 2.9.7-2.mga9
+ Revision: 1767398
- provide CImg-devel with devel pkg

* Sat Apr 10 2021 daviddavid <daviddavid> 2.9.7-1.mga9
+ Revision: 1714493
- new version: 2.9.7

* Tue Mar 02 2021 daviddavid <daviddavid> 2.9.6-1.mga9
+ Revision: 1696072
- new version: 2.9.6

* Tue Nov 24 2020 daviddavid <daviddavid> 2.9.4-1.mga8
+ Revision: 1649023
- new version: 2.9.4

* Tue Nov 24 2020 daviddavid <daviddavid> 2.9.3-1.mga8
+ Revision: 1648878
- new version: 2.9.3, fixes CVE-2020-25693 (mga#27651)

* Fri Oct 30 2020 joequant <joequant> 2.9.2-1.mga8
+ Revision: 1640733
- update to 2.9.2

* Sun Jul 12 2020 daviddavid <daviddavid> 2.9.1-1.mga8
+ Revision: 1605361
- new version: 2.9.1

* Wed Feb 19 2020 umeabot <umeabot> 2.8.3-3.mga8
+ Revision: 1544522
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 daviddavid <daviddavid> 2.8.3-2.mga8
+ Revision: 1483135
- add missing dependency on pkgconfig(OpenEXR) in devel subpkg

* Sun Jan 26 2020 daviddavid <daviddavid> 2.8.3-1.mga8
+ Revision: 1483118
- new version: 2.8.3

* Wed Oct 30 2019 daviddavid <daviddavid> 2.7.5-1.mga8
+ Revision: 1456796
- new version: 2.7.5

* Tue Sep 03 2019 daviddavid <daviddavid> 2.7.1-1.mga8
+ Revision: 1436543
- new version: 2.7.1

* Tue Aug 20 2019 daviddavid <daviddavid> 2.7.0-1.mga8
+ Revision: 1430429
- new version: 2.7.0

* Tue Jul 02 2019 daviddavid <daviddavid> 2.6.7-1.mga8
+ Revision: 1417556
- new version: 2.6.7

* Wed Apr 17 2019 daviddavid <daviddavid> 2.5.7-1.mga7
+ Revision: 1391859
- new version: 2.5.7

* Wed Apr 10 2019 daviddavid <daviddavid> 2.5.6-1.mga7
+ Revision: 1387839
- new version: 2.5.6

* Tue Apr 02 2019 daviddavid <daviddavid> 2.5.5-1.mga7
+ Revision: 1385342
- new version: 2.5.5

* Mon Mar 25 2019 daviddavid <daviddavid> 2.5.4-1.mga7
+ Revision: 1380050
- new version: 2.5.4

* Sun Mar 17 2019 daviddavid <daviddavid> 2.5.3-1.mga7
+ Revision: 1378406
- new version: 2.5.3

* Sun Mar 17 2019 daviddavid <daviddavid> 2.5.2-1.mga7
+ Revision: 1378203
- new version: 2.5.2

* Wed Jan 30 2019 daviddavid <daviddavid> 2.4.5-1.mga7
+ Revision: 1361875
- new version: 2.4.5

* Sat Dec 22 2018 daviddavid <daviddavid> 2.4.3-1.mga7
+ Revision: 1344408
- new version: 2.4.3

* Mon Dec 03 2018 daviddavid <daviddavid> 2.4.2-1.mga7
+ Revision: 1337966
- new version: 2.4.2
- rename and rediff arm patch

* Tue Oct 16 2018 daviddavid <daviddavid> 2.4.0-2.mga7
+ Revision: 1320744
- add patch to fix build on ARM

* Tue Oct 16 2018 daviddavid <daviddavid> 2.4.0-1.mga7
+ Revision: 1320729
- new version: 2.4.0, fixes multiple security issues (mga#23700)

* Sat Sep 22 2018 umeabot <umeabot> 2.2.1-2.mga7
+ Revision: 1296231
- Mageia 7 Mass Rebuild

* Fri Mar 23 2018 kekepower <kekepower> 2.2.1-1.mga7
+ Revision: 1211727
- Update to version 2.2.1

* Thu Jan 18 2018 shlomif <shlomif> 2.1.8-5.mga7
+ Revision: 1194422
- New version 2.1.8

* Sat Feb 13 2016 umeabot <umeabot> 1.5.9-5.mga6
+ Revision: 959696
- Mageia 6 Mass Rebuild

* Wed Sep 09 2015 neoclust <neoclust> 1.5.9-4.mga6
+ Revision: 874988
- Fix build with new rpm ( empty debuginfo)

* Wed Oct 15 2014 umeabot <umeabot> 1.5.9-3.mga5
+ Revision: 746237
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.9-2.mga5
+ Revision: 678394
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 akien <akien> 1.5.9-1.mga5
+ Revision: 674288
- Version 1.5.9

* Fri Oct 18 2013 umeabot <umeabot> 1.5.2-3.mga4
+ Revision: 503336
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 1.5.2-2.mga3
+ Revision: 347754
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Fri Dec 07 2012 dams <dams> 1.5.2-1.mga3
+ Revision: 327875
- new version 1.5.2
- update %%group

* Sun Jul 15 2012 dams <dams> 1.5.0-1.mga3
+ Revision: 270863
- add 'X11-devel' as 'BuildRequires'
- clean specfile
- imported package cimg

